kryptos.core


Baze64cljprotocol

decode-base64clj

(decode-base64 s target)

decode-base64-urlclj

(decode-base64-url s)

encode-base64clj

(encode-base64 x)

encode-base64-urlclj

(encode-base64-url x)

encode-base64-url-without-paddingclj

(encode-base64-url-without-padding x)

encode-base64-without-paddingclj

(encode-base64-without-padding x)
source

digestclj

(digest xs)
source

generate-symmetric-keyclj

(generate-symmetric-key)
source

hash-dgstclj

(hash-dgst bytes)
(hash-dgst s algo)

Single arity is suitable for PKCE code challenge, next signature is Sun implementation where s is string, algo is SHA-224, SHA-256, etc.

Single arity is suitable for PKCE code challenge, next signature is Sun implementation where s is string, algo is SHA-224, SHA-256, etc.
sourceraw docstring

new-telefunken-keyclj

(new-telefunken-key)
source

pem-string->public-keyclj

(pem-string->public-key s)
source

signcljmultimethod

source

sign-bytescljmultimethod

source

verify-hmacclj

(verify-hmac key data hmac)
source

verify-hmac-bytesclj

(verify-hmac-bytes key data hmac)
source

cljdoc builds & hosts documentation for Clojure/Script libraries