(decode-base64 s target)(decode-base64-url s)(encode-base64 x)(encode-base64-url x)(encode-base64-url-without-padding x)(encode-base64-without-padding x)(hash-dgst bytes)(hash-dgst s algo)Single arity is suitable for PKCE code challenge, next signature is Sun implementation where s is string, algo is SHA-224, SHA-256, etc.
Single arity is suitable for PKCE code challenge, next signature is Sun implementation where s is string, algo is SHA-224, SHA-256, etc.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |